@@ -198,26 +198,11 @@ gsd_datetime_manager_stop (GsdDatetimeManager *self)
         }
 }
 
-static GObject *
-gsd_datetime_manager_constructor (GType type,
-                                  guint n_construct_properties,
-                                  GObjectConstructParam *construct_properties)
-{
-        GsdDatetimeManager *m;
-
-        m = GSD_DATETIME_MANAGER (G_OBJECT_CLASS (gsd_datetime_manager_parent_class)->constructor (type,
-                                                                                                   n_construct_properties,
-                                                                                                   construct_properties));
-
-        return G_OBJECT (m);
-}
-
 static void
 gsd_datetime_manager_class_init (GsdDatetimeManagerClass *klass)
 {
         GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-        object_class->constructor = gsd_datetime_manager_constructor;
         object_class->finalize = gsd_datetime_manager_finalize;
 
         g_type_class_add_private (klass, sizeof (GsdDatetimeManagerPrivate));
