@@ -89,33 +89,11 @@ G_DEFINE_TYPE (GsdOrientationManager, gsd_orientation_manager, G_TYPE_OBJECT)
 
 static gpointer manager_object = NULL;
 
-static GObject *
-gsd_orientation_manager_constructor (GType                     type,
-                               guint                      n_construct_properties,
-                               GObjectConstructParam     *construct_properties)
-{
-        GsdOrientationManager      *orientation_manager;
-
-        orientation_manager = GSD_ORIENTATION_MANAGER (G_OBJECT_CLASS (gsd_orientation_manager_parent_class)->constructor (type,
-                                                                                                         n_construct_properties,
-                                                                                                         construct_properties));
-
-        return G_OBJECT (orientation_manager);
-}
-
-static void
-gsd_orientation_manager_dispose (GObject *object)
-{
-        G_OBJECT_CLASS (gsd_orientation_manager_parent_class)->dispose (object);
-}
-
 static void
 gsd_orientation_manager_class_init (GsdOrientationManagerClass *klass)
 {
         GObjectClass   *object_class = G_OBJECT_CLASS (klass);
 
-        object_class->constructor = gsd_orientation_manager_constructor;
-        object_class->dispose = gsd_orientation_manager_dispose;
         object_class->finalize = gsd_orientation_manager_finalize;
 
         g_type_class_add_private (klass, sizeof (GsdOrientationManagerPrivate));
